.. django-feedaggregator documentation master file, created by
   sphinx-quickstart on Thu May 28 18:20:58 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-feedaggregator's documentation!
=================================================

Django-feedaggregator is an RSS/Atom feed aggregator (planet) for Django 1.8.


Contents:

.. toctree::
   :maxdepth: 2

   installation
   configuration
   commands
   templatetags

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

